@@ -18,7 +18,6 @@
 #include "pqxx/compiler.h"
 
 #include <algorithm>
-#include <cassert>
 
 #include "pqxx/dbtransaction"
 #include "pqxx/pipeline"
@@ -27,6 +26,7 @@ using namespace PGSTD;
 using namespace pqxx;
 using namespace pqxx::internal::pq;
 
+#define pqxxassert(ARG) /* ignore */
 
 namespace
 {
@@ -47,7 +47,6 @@ pqxx::pipeline::pipeline(transaction_base &t, const string &PName) :
   m_error(qid_limit())
 {
   m_issuedrange = make_pair(m_queries.end(), m_queries.end());
-  invariant();
   register_me();
 }
 
@@ -61,11 +60,9 @@ pqxx::pipeline::~pipeline() throw ()
 
 pipeline::query_id pqxx::pipeline::insert(const string &q)
 {
-  invariant();
-
   const query_id qid = generate_id();
-  assert(qid > 0);
-  assert(m_queries.lower_bound(qid)==m_queries.end());
+  pqxxassert(qid > 0);
+  pqxxassert(m_queries.lower_bound(qid)==m_queries.end());
   const QueryMap::iterator i = m_queries.insert(make_pair(qid,Query(q))).first;
 
   if (m_issuedrange.second == m_queries.end())
@@ -75,9 +72,8 @@ pipeline::query_id pqxx::pipeline::insert(const string &q)
   }
   m_num_waiting++;
 
-  assert(m_issuedrange.first != m_queries.end());
-  assert(m_issuedrange.second != m_queries.end());
-  invariant();
+  pqxxassert(m_issuedrange.first != m_queries.end());
+  pqxxassert(m_issuedrange.second != m_queries.end());
 
   if (m_num_waiting > m_retain)
   {
@@ -85,45 +81,36 @@ pipeline::query_id pqxx::pipeline::insert(const string &q)
     if (!have_pending()) issue();
   }
 
-  invariant();
-
   return qid;
 }
 
 
 void pqxx::pipeline::complete()
 {
-  invariant();
-
   if (have_pending()) receive(m_issuedrange.second);
   if (m_num_waiting && (m_error == qid_limit()))
   {
-    assert(!have_pending());
+    pqxxassert(!have_pending());
     issue();
-    assert(!m_num_waiting);
-    assert(have_pending());
-    assert(m_issuedrange.second == m_queries.end());
+    pqxxassert(!m_num_waiting);
+    pqxxassert(have_pending());
+    pqxxassert(m_issuedrange.second == m_queries.end());
     receive(m_queries.end());
-    assert((m_error!=qid_limit()) || !have_pending());
+    pqxxassert((m_error!=qid_limit()) || !have_pending());
   }
-  invariant();
-  assert((m_num_waiting == 0) || (m_error != qid_limit()));
-  assert(!m_dummy_pending);
+  pqxxassert((m_num_waiting == 0) || (m_error != qid_limit()));
+  pqxxassert(!m_dummy_pending);
 }
 
 
 void pqxx::pipeline::flush()
 {
-  invariant();
-
   if (m_queries.empty()) return;
   if (have_pending()) receive(m_issuedrange.second);
   m_issuedrange.first = m_issuedrange.second = m_queries.end();
   m_num_waiting = 0;
   m_dummy_pending = false;
   m_queries.clear();
-
-  invariant();
 }
 
 
@@ -146,8 +133,6 @@ pair<pipeline::query_id, result> pqxx::pipeline::retrieve()
 
 int pqxx::pipeline::retain(int retain_max)
 {
-  invariant();
-
   if (retain_max < 0)
     throw range_error("Attempt to make pipeline retain " +
 	to_string(retain_max) + " queries");
@@ -157,69 +142,18 @@ int pqxx::pipeline::retain(int retain_max)
 
   if (m_num_waiting >= m_retain) resume();
 
-  invariant();
-
   return oldvalue;
 }
 
 
 void pqxx::pipeline::resume()
 {
-  invariant();
-
   if (have_pending()) receive_if_available();
   if (!have_pending() && m_num_waiting)
   {
     issue();
     receive_if_available();
   }
-
-  invariant();
-}
-
-
-void pqxx::pipeline::invariant() const
-{
-  assert(m_q_id >= 0);
-  assert(m_q_id <= qid_limit());
-
-  assert(m_retain >= 0);
-  assert(m_num_waiting >= 0);
-
-  const QueryMap::const_iterator 
-    start_of_issued = m_issuedrange.first,
-    end_of_issued = m_issuedrange.second;
-
-  if (m_queries.empty()) assert(start_of_issued==m_queries.end());
-  assert(distance(m_queries.begin(), start_of_issued) >= 0);
-  assert(distance(m_issuedrange.first, m_issuedrange.second) >= 0);
-  assert(distance(end_of_issued, m_queries.end()) >= 0);
-
-  if (!m_queries.empty())
-  {
-    assert(m_queries.begin()->first > 0);
-    assert(m_queries.rbegin()->first < (m_q_id+1));
-
-    assert(m_num_waiting >= 0);
-    assert(size_t(m_num_waiting) <= size_t(m_queries.size()));
-
-    if (have_pending())
-    {
-      assert(m_issuedrange.first != m_queries.end());
-      if (m_error == qid_limit())
-        assert(m_num_waiting == distance(end_of_issued, m_queries.end()));
-    }
-  }
-  else
-  {
-    assert(m_issuedrange.first == m_queries.end());
-    assert(m_issuedrange.second == m_queries.end());
-    assert(!have_pending());
-    assert(!m_num_waiting);
-    assert(!m_dummy_pending);
-  }
-
-  assert(m_error != 0);
 }
 
 
@@ -234,11 +168,10 @@ pipeline::query_id pqxx::pipeline::generate_id()
 
 void pqxx::pipeline::issue()
 {
-  assert(m_num_waiting);
-  assert(!have_pending());
-  assert(!m_dummy_pending);
-  assert(m_num_waiting);
-  invariant();
+  pqxxassert(m_num_waiting);
+  pqxxassert(!have_pending());
+  pqxxassert(!m_dummy_pending);
+  pqxxassert(m_num_waiting);
 
   // Retrieve that NULL result for the last query, if needed
   obtain_result();
@@ -248,7 +181,7 @@ void pqxx::pipeline::issue()
 
   // Start with oldest query (lowest id) not in previous issue range
   const QueryMap::iterator oldest = m_issuedrange.second;
-  assert(oldest != m_queries.end());
+  pqxxassert(oldest != m_queries.end());
 
   // Construct cumulative query string for entire batch
   string cum;
@@ -271,8 +204,6 @@ void pqxx::pipeline::issue()
   m_issuedrange.first = oldest;
   m_issuedrange.second = m_queries.end();
   m_num_waiting -= num_issued;
-
-  invariant();
 }
 
 
@@ -285,9 +216,8 @@ void pqxx::pipeline::internal_error(const string &err) throw (logic_error)
 
 bool pqxx::pipeline::obtain_result(bool expect_none)
 {
-  assert(!m_dummy_pending);
-  assert(!m_queries.empty());
-  invariant();
+  pqxxassert(!m_dummy_pending);
+  pqxxassert(!m_queries.empty());
 
   internal::pq::PGresult *r = m_Trans.get_result();
   if (!r)
@@ -300,7 +230,7 @@ bool pqxx::pipeline::obtain_result(bool expect_none)
     return false;
   }
 
-  assert(r);
+  pqxxassert(r);
   const result res(r);
 
   if (!have_pending())
@@ -316,15 +246,13 @@ bool pqxx::pipeline::obtain_result(bool expect_none)
   m_issuedrange.first->second.set_result(res);
   ++m_issuedrange.first;
 
-  invariant();
-
   return true;
 }
 
 
 void pqxx::pipeline::obtain_dummy()
 {
-  assert(m_dummy_pending);
+  pqxxassert(m_dummy_pending);
   internal::pq::PGresult *const r = m_Trans.get_result();
   m_dummy_pending = false;
 
@@ -376,9 +304,9 @@ void pqxx::pipeline::obtain_dummy()
   m_num_waiting += distance(m_issuedrange.first, stop);
   m_issuedrange.second = m_issuedrange.first;
 
-  assert(!m_dummy_pending);
-  assert(!have_pending());
-  assert(m_num_waiting > 0);
+  pqxxassert(!m_dummy_pending);
+  pqxxassert(!have_pending());
+  pqxxassert(m_num_waiting > 0);
 
   // Issue queries in failed batch one at a time.
   unregister_me();
@@ -397,7 +325,7 @@ void pqxx::pipeline::obtain_dummy()
   }
   catch (const exception &e)
   {
-    assert(m_issuedrange.first != m_queries.end());
+    pqxxassert(m_issuedrange.first != m_queries.end());
 
     const query_id thud = m_issuedrange.first->first;
     ++m_issuedrange.first;
@@ -405,20 +333,17 @@ void pqxx::pipeline::obtain_dummy()
     QueryMap::const_iterator q = m_issuedrange.first;
     set_error_at( (q == m_queries.end()) ?  thud + 1 : q->first);
 
-    assert(m_num_waiting == distance(m_issuedrange.second, m_queries.end()));
+    pqxxassert(m_num_waiting == distance(m_issuedrange.second, m_queries.end()));
   }
 
-  assert(m_issuedrange.first != m_queries.end());
-  assert(m_error <= m_q_id);
-  invariant();
+  pqxxassert(m_issuedrange.first != m_queries.end());
+  pqxxassert(m_error <= m_q_id);
 }
 
 
 pair<pipeline::query_id, result>
 pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
 {
-  invariant();
-
   if (q == m_queries.end())
     throw logic_error("Attempt to retrieve result for unknown query");
 
@@ -430,7 +355,7 @@ pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
   if (m_issuedrange.second != m_queries.end() && 
       (q->first >= m_issuedrange.second->first))
   {
-    assert(distance(m_issuedrange.second, q) >= 0);
+    pqxxassert(distance(m_issuedrange.second, q) >= 0);
 
     if (have_pending()) receive(m_issuedrange.second);
     if (m_error == qid_limit()) issue();
@@ -451,7 +376,7 @@ pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
     }
   }
 
-  assert((m_error <= q->first) || (q != m_issuedrange.first));
+  pqxxassert((m_error <= q->first) || (q != m_issuedrange.first));
 
   if (q->first >= m_error)
     throw runtime_error("Could not complete query in pipeline "
@@ -466,8 +391,6 @@ pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
 
   m_queries.erase(q);
 
-  invariant();
-
   R.CheckStatus(query);
   return P;
 }
@@ -475,29 +398,24 @@ pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
 
 void pqxx::pipeline::get_further_available_results()
 {
-  assert(!m_dummy_pending);
+  pqxxassert(!m_dummy_pending);
   while (!m_Trans.is_busy() && obtain_result()) m_Trans.consume_input();
 }
 
 
 void pqxx::pipeline::receive_if_available()
 {
-  invariant();
-
   m_Trans.consume_input();
   if (m_Trans.is_busy()) return;
 
   if (m_dummy_pending) obtain_dummy();
   if (have_pending()) get_further_available_results();
-
-  invariant();
 }
 
 
 void pqxx::pipeline::receive(pipeline::QueryMap::const_iterator stop)
 {
-  invariant();
-  assert(have_pending());
+  pqxxassert(have_pending());
 
   if (m_dummy_pending) obtain_dummy();
 
